@@ -9,6 +9,7 @@ from pre_commit import git
 from pre_commit import color
 from pre_commit.logging_handler import LoggingHandler
 from pre_commit.output import get_hook_message
+from pre_commit.output import sys_stdout_write_wrapper
 from pre_commit.staged_files_only import staged_files_only
 from pre_commit.util import noop_context
 
@@ -47,18 +48,18 @@ def _print_user_skipped(hook, write, args):
     ))
 
 
-def _run_single_hook(runner, repository, hook_id, args, write, skips=set()):
-    if args.all_files:
+def _run_single_hook(runner, repository, hook, args, write, skips=set()):
+    if args.files:
+        get_filenames = git.get_files_matching(lambda: args.files)
+    elif args.all_files:
         get_filenames = git.get_all_files_matching
     elif git.is_in_merge_conflict():
         get_filenames = git.get_conflicted_files_matching
     else:
         get_filenames = git.get_staged_files_matching
 
-    hook = repository.hooks[hook_id]
-
     filenames = get_filenames(hook['files'], hook['exclude'])
-    if hook_id in skips:
+    if hook['id'] in skips:
         _print_user_skipped(hook, write, args)
         return 0
     elif not filenames:
@@ -70,9 +71,9 @@ def _run_single_hook(runner, repository, hook_id, args, write, skips=set()):
     write(get_hook_message(_hook_msg_start(hook, args.verbose), end_len=6))
     sys.stdout.flush()
 
-    retcode, stdout, stderr = repository.run_hook(hook_id, filenames)
+    retcode, stdout, stderr = repository.run_hook(hook, filenames)
 
-    if retcode != repository.hooks[hook_id]['expected_return_value']:
+    if retcode != hook['expected_return_value']:
         retcode = 1
         print_color = color.RED
         pass_fail = 'Failed'
@@ -84,6 +85,7 @@ def _run_single_hook(runner, repository, hook_id, args, write, skips=set()):
     write(color.format_color(pass_fail, print_color, args.color) + '\n')
 
     if (stdout or stderr) and (retcode or args.verbose):
+        write('hookid: {0}\n'.format(hook['id']))
         write('\n')
         for output in (stdout, stderr):
             if output.strip():
@@ -100,9 +102,9 @@ def _run_hooks(runner, args, write, environ):
     skips = _get_skips(environ)
 
     for repo in runner.repositories:
-        for hook_id in repo.hooks:
+        for _, hook in repo.hooks:
             retval |= _run_single_hook(
-                runner, repo, hook_id, args, write, skips=skips,
+                runner, repo, hook, args, write, skips=skips,
             )
 
     return retval
@@ -111,8 +113,11 @@ def _run_hooks(runner, args, write, environ):
 def _run_hook(runner, args, write):
     hook_id = args.hook
     for repo in runner.repositories:
-        if hook_id in repo.hooks:
-            return _run_single_hook(runner, repo, hook_id, args, write=write)
+        for hook_id_in_repo, hook in repo.hooks:
+            if hook_id == hook_id_in_repo:
+                return _run_single_hook(
+                    runner, repo, hook, args, write=write,
+                )
     else:
         write('No hook with id `{0}`\n'.format(hook_id))
         return 1
@@ -123,7 +128,7 @@ def _has_unmerged_paths(runner):
     return bool(stdout.strip())
 
 
-def run(runner, args, write=sys.stdout.write, environ=os.environ):
+def run(runner, args, write=sys_stdout_write_wrapper, environ=os.environ):
     # Set up our logging handler
     logger.addHandler(LoggingHandler(args.color, write=write))
     logger.setLevel(logging.INFO)
@@ -133,7 +138,8 @@ def run(runner, args, write=sys.stdout.write, environ=os.environ):
         logger.error('Unmerged files.  Resolve before committing.')
         return 1
 
-    if args.no_stash or args.all_files:
+    # Don't stash if specified or files are specified
+    if args.no_stash or args.all_files or args.files:
         ctx = noop_context()
     else:
         ctx = staged_files_only(runner.cmd_runner)
