@@ -2,6 +2,7 @@ from __future__ import unicode_literals
 
 import argparse
 import pkg_resources
+import sys
 
 from pre_commit import color
 from pre_commit.commands.autoupdate import autoupdate
@@ -9,12 +10,12 @@ from pre_commit.commands.clean import clean
 from pre_commit.commands.install_uninstall import install
 from pre_commit.commands.install_uninstall import uninstall
 from pre_commit.commands.run import run
+from pre_commit.error_handler import error_handler
 from pre_commit.runner import Runner
-from pre_commit.util import entry
 
 
-@entry
-def main(argv):
+def main(argv=None):
+    argv = argv if argv is not None else sys.argv[1:]
     parser = argparse.ArgumentParser()
 
     # http://stackoverflow.com/a/8521644/812183
@@ -29,7 +30,7 @@ def main(argv):
     subparsers = parser.add_subparsers(dest='command')
 
     install_parser = subparsers.add_parser(
-        'install', help='Intall the pre-commit script.',
+        'install', help='Install the pre-commit script.',
     )
     install_parser.add_argument(
         '-f', '--overwrite', action='store_true',
@@ -47,14 +48,13 @@ def main(argv):
 
     subparsers.add_parser('clean', help='Clean out pre-commit files.')
 
-    subparsers.add_parser('autoupdate', help='Auto-update hooks config.')
+    subparsers.add_parser(
+        'autoupdate',
+        help="Auto-update pre-commit config to the latest repos' versions.",
+    )
 
     run_parser = subparsers.add_parser('run', help='Run hooks.')
     run_parser.add_argument('hook', nargs='?', help='A single hook-id to run')
-    run_parser.add_argument(
-        '--all-files', '-a', action='store_true', default=False,
-        help='Run on all the files in the repo.  Implies --no-stash.',
-    )
     run_parser.add_argument(
         '--color', default='auto', type=color.use_color,
         help='Whether to use color in output.  Defaults to `auto`',
@@ -66,6 +66,14 @@ def main(argv):
     run_parser.add_argument(
         '--verbose', '-v', action='store_true', default=False,
     )
+    run_mutex_group = run_parser.add_mutually_exclusive_group(required=False)
+    run_mutex_group.add_argument(
+        '--all-files', '-a', action='store_true', default=False,
+        help='Run on all the files in the repo.  Implies --no-stash.',
+    )
+    run_mutex_group.add_argument(
+        '--files', nargs='*', help='Specific filenames to run hooks on.',
+    )
 
     help = subparsers.add_parser(
         'help', help='Show help for a specific command.'
@@ -83,28 +91,29 @@ def main(argv):
         else:
             parser.parse_args(['--help'])
 
-    runner = Runner.create()
+    with error_handler():
+        runner = Runner.create()
 
-    if args.command == 'install':
-        return install(
-            runner, overwrite=args.overwrite, hooks=args.install_hooks,
-        )
-    elif args.command == 'uninstall':
-        return uninstall(runner)
-    elif args.command == 'clean':
-        return clean(runner)
-    elif args.command == 'autoupdate':
-        return autoupdate(runner)
-    elif args.command == 'run':
-        return run(runner, args)
-    else:
-        raise NotImplementedError(
-            'Command {0} not implemented.'.format(args.command)
-        )
+        if args.command == 'install':
+            return install(
+                runner, overwrite=args.overwrite, hooks=args.install_hooks,
+            )
+        elif args.command == 'uninstall':
+            return uninstall(runner)
+        elif args.command == 'clean':
+            return clean(runner)
+        elif args.command == 'autoupdate':
+            return autoupdate(runner)
+        elif args.command == 'run':
+            return run(runner, args)
+        else:
+            raise NotImplementedError(
+                'Command {0} not implemented.'.format(args.command)
+            )
 
-    raise AssertionError(
-        'Command {0} failed to exit with a returncode'.format(args.command)
-    )
+        raise AssertionError(
+            'Command {0} failed to exit with a returncode'.format(args.command)
+        )
 
 
 if __name__ == '__main__':
